Some cleanup of block API code.


git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@119174 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/CGBlocks.h b/lib/CodeGen/CGBlocks.h
index a5f2aa9..f82ce11 100644
--- a/lib/CodeGen/CGBlocks.h
+++ b/lib/CodeGen/CGBlocks.h
@@ -154,8 +154,8 @@
   /// for a value with the given size and alignment requirements.
   CharUnits getBlockOffset(CharUnits Size, CharUnits Align);
 
-  /// BlockHasCopyDispose - True iff the block uses copy/dispose.
-  bool BlockHasCopyDispose;
+  /// SynthesizeCopyDisposeHelpers - True iff the block uses copy/dispose.
+  bool SynthesizeCopyDisposeHelpers;
 
   /// BlockLayout - The layout of the block's storage, represented as
   /// a sequence of expressions which require such storage.  The
@@ -179,9 +179,9 @@
   ImplicitParamDecl *BlockStructDecl;
   ImplicitParamDecl *getBlockStructDecl() { return BlockStructDecl; }
 
-  llvm::Constant *GenerateCopyHelperFunction(bool, const llvm::StructType *,
+  llvm::Constant *GenerateCopyHelperFunction(const llvm::StructType *,
                                              std::vector<HelperInfo> *);
-  llvm::Constant *GenerateDestroyHelperFunction(bool, const llvm::StructType *,
+  llvm::Constant *GenerateDestroyHelperFunction(const llvm::StructType *,
                                                 std::vector<HelperInfo> *);
 
   llvm::Constant *BuildCopyHelper(const llvm::StructType *,